@@ -32,6 +32,7 @@ except ImportError:
 # Import ioflo libs
 from .globaling import *
 from .odicting import odict
+from . import excepting
 
 from .consoling import getConsole
 console = getConsole()
@@ -120,48 +121,6 @@ def nonStringSequence(obj):
     """
     return (not isinstance(obj, basestring) and isinstance(obj, Sequence) )
 
-class Fifo(deque):  #new-style class to add put get methods
-    """ Extends deque to support more convenient FIFO queue access
-
-       for any python sequence to determine if it is empty just use "if s:"
-
-       local methods
-       .put inserts non-None item at tail, back (right side) of deque
-       .get retrieves item from head, front, (left side) of deque, None if empty
-
-
-       inherited methods:
-       .append()  = add to right side of deque
-       .appendleft() = add to left side of deque
-       .clear()  = clear items from deque
-       .extend() = append iterable
-       .extendleft = appendleft iterable
-       .pop() = remove from right side
-       .popleft() = remove from left side
-       .remove() = remove first occurence of value left to right
-       .rotate() = rotate to right if neg rotate to left
-       .reversed() = copy of deque reversed
-    """
-
-    def put(self, item):
-        """Puts item at tail of queue = back of deque
-           If item is None don't put on Queue. Symmetric with get which returns
-           None if queue empty
-        """
-        if item is not None:
-            self.append(item)
-
-    def get(self):
-        """Returns item from head of fifo = front of deque
-           If empty returns None  (therefore None is not allowed as item in fifo)
-        """
-        try:
-            item = self.popleft()
-        except IndexError:
-            item = None
-
-        return item
-
 class Timer(object):
     """ Class to manage real elaspsed time.  needs time module
         attributes:
@@ -190,7 +149,7 @@ class Timer(object):
         """ Computes elapsed time in seconds (fractional) since start.
             if zero then hasn't started yet
         """
-        return abs(time.time() - self.start)
+        return max(0.0, time.time() - self.start)
     elapsed = property(getElapsed, doc='Elapsed time.')
 
     def getRemaining(self):# for property
@@ -248,8 +207,130 @@ class Timer(object):
 
         return self.restart(start=self.start, duration=duration)
 
+class MonoTimer(object):
+    """ Class to manage real elaspsed time with monotonic guarantee.
+        If the system clock is retrograded (moved back in time)
+        while the timer is running then time.time() could move
+        to before the start time.
+        A MonoTimer detects this retrograde and if adjust is True then
+        shifts the timer back otherwise it raises a TimerRetroError
+        exception.
+        This timer is not able to detect a prograded clock
+        (moved forward in time)
+
+        Needs time module
+        attributes:
+        .duration = time duration of timer start to stop
+        .start = time started
+        .stop = time when timer expires
+        .base = real time when started or restarted
+        .prev = real time when checked
+
+        properties:
+        .elaspsed = time elasped since start
+        .remaining = time remaining until stop
+        .expired = True if expired, False otherwise
+
+        methods:
+        .extend() = extends/shrinks timer duration
+        .repeat() = restarts timer at last .stop so no time lost
+        .restart() = restarts timer
+    """
+
+    def __init__(self, duration = 0.0, adjust=False):
+        """ Initialization method for instance.
+            duration in seconds (fractional)
+        """
+        self.adjust = True if adjust else False
+        self.start = None
+        self.stop = None
+        self.latest = time.time()  # last time checked current time
+        self.restart(start=self.latest, duration=duration)
+
+    def update(self):
+        '''
+        Updates .latest to current time.
+        Checks for retrograde movement of system time.time() and either
+        raises a TimerRetroErrorexception or adjusts the timer attributes to compensate.
+        '''
+        delta = time.time() - self.latest  # current time - last time checked
+        if delta < 0:  # system clock has retrograded
+            if not self.adjust:
+                raise excepting.TimerRetroError("Timer retrograded by {0} "
+                                                "seconds\n".format(delta))
+            self.start = self.start + delta
+            self.stop = self.stop + delta
+
+        self.latest += delta
+
+    def getElapsed(self): #for property
+        """ Computes elapsed time in seconds (fractional) since start.
+            if zero then hasn't started yet
+        """
+        self.update()
+        return max(0.0, self.latest - self.start)
+    elapsed = property(getElapsed, doc='Elapsed time.')
+
+    def getRemaining(self):# for property
+        """ Returns time remaining in seconds (fractional) before expires.
+            returns zero if it has already expired
+        """
+        self.update()
+        return max(0.0, self.stop - self.latest)
+    remaining = property(getRemaining, doc='Remaining time.')
+
+    def getExpired(self):
+        self.update()
+        if (self.latest >= self.stop):
+            return True
+        else:
+            return False
+    expired = property(getExpired, doc='True if expired, False otherwise')
+
+    def restart(self,start=None, duration=None):
+        """ Starts timer at start time secs for duration secs.
+            (fractional from epoc)
+            If start arg is missing then restarts at current time
+            If duration arg is missing then restarts for current duration
+        """
+        self.update()
+        if start is not None:
+            self.start = abs(start) #must be non negative
+        else: #use current time
+            self.start = self.latest
+
+        if duration is not None:
+            self.duration = abs(duration) #must be non negative
+        #Otherwise keep old duration
+
+        self.stop = self.start + self.duration
+
+        return (self.start, self.stop)
+
+    def repeat(self):
+        """ Restarts timer at stop so no time lost
+
+        """
+        return self.restart(start=self.stop)
+
+    def extend(self, extension=None):
+        """ Extends timer duration for additional extension seconds (fractional).
+            Useful so as not to lose time when  need more/less time on timer
+
+            If extension negative then shortens existing duration
+            If extension arg missing then extends for the existing duration
+            effectively doubling the time
+
+        """
+        if extension is None: #otherwise extend by .duration or double
+            extension = self.duration
+
+        duration = self.duration + extension
+
+        return self.restart(start=self.start, duration=duration)
+
 class StoreTimer(object):
-    """ Class to manage realtive Store based time.
+    """ Class to manage relative Store based time.
         Uses Store instance .stamp attribute as current time
         Attributes:
         .duration = time duration of timer start to stop
@@ -280,7 +361,7 @@ class StoreTimer(object):
         """ Computes elapsed time in seconds (fractional) since start.
             if zero then hasn't started yet
         """
-        return abs(self.store.stamp - self.start)
+        return max(0.0, self.store.stamp - self.start)
     elapsed = property(getElapsed, doc='Elapsed time.')
 
     def getRemaining(self):# for property
@@ -2220,16 +2301,22 @@ def CRC64(inpkt) :
 
 crc64 = CRC64 # alias
 
-def Ocfn(filename, openMode = 'r+'):
+def Ocfn(filename, openMode = 'r+', binary=False):
     """Atomically open or create file from filename.
 
        If file already exists, Then open file using openMode
-       Else create file using write update mode
+       Else create file using write update mode If not binary Else
+           write update binary mode
        Returns file object
+
+       If binary Then If new file open with write update binary mode
     """
     try:
         newfd = os.open(filename, os.O_EXCL | os.O_CREAT | os.O_RDWR, 436) # 436 == octal 0664
-        newfile = os.fdopen(newfd,"w+")
+        if not binary:
+            newfile = os.fdopen(newfd,"w+")
+        else:
+            newfile = os.fdopen(newfd,"w+b")
     except OSError as ex:
         if ex.errno == errno.EEXIST:
             newfile = open(filename, openMode)
