@@ -125,8 +125,8 @@ class Skedder(object):
         self.stamp = float(abs(stamp))
         #real time or sim time mode
         self.real = True if real else False
-        self.timer = aiding.Timer(duration = self.period)
-        self.elapsed = aiding.Timer()
+        self.timer = aiding.MonoTimer(duration = self.period, adjust=True)
+        self.elapsed = aiding.MonoTimer(adjust=True)
 
         self.filepath = os.path.abspath(filepath)
         self.plan = os.path.split(self.filepath)[1]
