@@ -33,19 +33,19 @@ class Want(acting.Actor):
     """
     Registry = odict()
 
-    def resolve(self, taskers, **kwa):
+    def _resolve(self, taskers, **kwa):
         """Resolves value taskers list of links that is passed in as parm
            resolved links are passed back to act to store in parms
            since tasker may not be current framer at build time
         """
-        parms = super(Want, self).resolve( **kwa)
+        parms = super(Want, self)._resolve( **kwa)
         links = set()
         for tasker in taskers:
             if tasker == 'all':
                 for tasker in self.store.house.taskables:
                     links.add(tasker)
             elif tasker == 'me':
-                tasker = self.act.frame.framer
+                tasker = self._act.frame.framer
                 links.add(tasker)
 
             else:
@@ -53,8 +53,8 @@ class Want(acting.Actor):
                                                who=self.name,
                                                desc='tasker',
                                                contexts=[ACTIVE, INACTIVE],
-                                               human=self.act.human,
-                                               count=self.act.count)
+                                               human=self._act.human,
+                                               count=self._act.count)
                 links.add(tasker)
 
         parms['taskers'] = links #replace with valid list
